@@ -52,7 +52,7 @@ checkFactorLevels = function(x , levels = NULL, ordered = NA, empty.levels.ok =
     }
     qassert(empty.levels.ok, "B1")
     if (!empty.levels.ok) {
-      empty = setdiff(levels(x), levels(droplevels(x)))
+      empty = setdiff(levels(x), x)
       if (length(empty) > 0L)
         return(sprintf("Has has empty levels '%s'", paste0(empty, collapse = "','")))
     }
@@ -83,7 +83,7 @@ check_factor = checkFactor
 #' @include makeAssertion.R
 #' @template assert
 #' @rdname checkFactor
-assertFactor = makeAssertionFunction(checkFactor)
+assertFactor = makeAssertionFunction(checkFactor, use.namespace = FALSE)
 
 #' @export
 #' @rdname checkFactor
@@ -102,4 +102,4 @@ test_factor = testFactor
 #' @include makeExpectation.R
 #' @template expect
 #' @rdname checkFactor
-expect_factor = makeExpectationFunction(checkFactor)
+expect_factor = makeExpectationFunction(checkFactor, use.namespace = FALSE)
