@@ -1,13 +1,13 @@
 #include "checkmate.h"
 
-Rboolean attribute_hidden qtest(SEXP x, const char *rule) {
+Rboolean qtest(SEXP x, const char *rule) {
   static Rboolean(*fun)(SEXP, const char *) = NULL;
   if (fun == NULL)
     fun = (Rboolean(*)(SEXP, const char *)) R_GetCCallable("checkmate", "qtest");
   return fun(x, rule);
 }
 
-SEXP attribute_hidden qassert(SEXP x, const char *rule, const char *name) {
+SEXP qassert(SEXP x, const char *rule, const char *name) {
   static SEXP(*fun)(SEXP, const char *, const char *) = NULL;
   if (fun == NULL)
     fun = (SEXP(*)(SEXP, const char *, const char *)) R_GetCCallable("checkmate", "qassert");
